@@ -1,5 +1,93 @@
 var NAVTREEINDEX17 =
 {
+"module_8h.html":[10,4,9,0],
+"modules.html":[10],
+"monitor_2event_8h.html":[10,8,4,1],
+"monitor_2type-info_8h.html":[10,8,4,2],
+"multiview_8h.html":[10,8,7,16],
+"names_8h.html":[10,8,8,8,0],
+"node_2command_8h.html":[10,8,6,0],
+"node_2event_8h.html":[10,8,6,1],
+"node_2type-info_8h.html":[10,8,6,5],
+"page_access.html":[5,5],
+"page_access.html#autotoc_md10":[5,5,0],
+"page_access.html#autotoc_md11":[5,5,0,0],
+"page_access.html#autotoc_md12":[5,5,0,1],
+"page_access.html#autotoc_md13":[5,5,0,2],
+"page_access.html#autotoc_md14":[5,5,0,3],
+"page_access.html#autotoc_md15":[5,5,0,4],
+"page_access.html#autotoc_md16":[5,5,1],
+"page_access.html#autotoc_md17":[5,5,1,0],
+"page_access.html#autotoc_md18":[5,5,1,1],
+"page_access.html#autotoc_md19":[5,5,1,2],
+"page_api.html":[8],
+"page_audio.html":[5,4],
+"page_audio.html#autotoc_md100":[5,4,0,5],
+"page_audio.html#autotoc_md101":[5,4,0,6],
+"page_audio.html#autotoc_md102":[5,4,1],
+"page_audio.html#autotoc_md103":[5,4,1,0],
+"page_audio.html#autotoc_md104":[5,4,1,1],
+"page_audio.html#autotoc_md105":[5,4,1,2],
+"page_audio.html#autotoc_md106":[5,4,2],
+"page_audio.html#autotoc_md107":[5,4,2,0],
+"page_audio.html#autotoc_md94":[5,4,0],
+"page_audio.html#autotoc_md95":[5,4,0,0],
+"page_audio.html#autotoc_md96":[5,4,0,1],
+"page_audio.html#autotoc_md97":[5,4,0,2],
+"page_audio.html#autotoc_md98":[5,4,0,3],
+"page_audio.html#autotoc_md99":[5,4,0,4],
+"page_client_impl.html":[8,0],
+"page_client_impl.html#sec_page_client_impl_credentials":[8,0,1],
+"page_client_impl.html#sec_page_client_impl_overview":[8,0,0],
+"page_client_impl.html#sec_page_client_impl_resources":[8,0,3],
+"page_client_impl.html#sec_page_client_impl_types":[8,0,2],
+"page_daemon.html":[5,11],
+"page_daemon.html#autotoc_md42":[5,11,0],
+"page_daemon.html#autotoc_md43":[5,11,0,0],
+"page_daemon.html#autotoc_md44":[5,11,1],
+"page_design.html":[5,3],
+"page_design.html#autotoc_md8":[5,3,0],
+"page_design.html#autotoc_md9":[5,3,1],
+"page_dma_buf.html":[5,10],
+"page_dma_buf.html#autotoc_md157":[5,10,0],
+"page_dma_buf.html#autotoc_md158":[5,10,0,0],
+"page_dma_buf.html#autotoc_md159":[5,10,0,1],
+"page_dma_buf.html#autotoc_md160":[5,10,0,1,0],
+"page_dma_buf.html#autotoc_md161":[5,10,0,1,1],
+"page_dma_buf.html#autotoc_md162":[5,10,0,2],
+"page_dma_buf.html#autotoc_md163":[5,10,0,3],
+"page_dma_buf.html#autotoc_md164":[5,10,0,4],
+"page_dma_buf.html#autotoc_md165":[5,10,1],
+"page_dma_buf.html#autotoc_md166":[5,10,2],
+"page_dma_buf.html#autotoc_md167":[5,10,3],
+"page_examples.html":[7,7],
+"page_library.html":[5,9],
+"page_library.html#autotoc_md45":[5,9,0],
+"page_library.html#autotoc_md46":[5,9,1],
+"page_library.html#autotoc_md47":[5,9,2],
+"page_library.html#autotoc_md48":[5,9,3],
+"page_library.html#autotoc_md49":[5,9,3,0],
+"page_library.html#autotoc_md50":[5,9,3,1],
+"page_library.html#autotoc_md51":[5,9,3,2],
+"page_library.html#autotoc_md52":[5,9,3,3],
+"page_library.html#autotoc_md53":[5,9,3,4],
+"page_library.html#autotoc_md54":[5,9,3,5],
+"page_library.html#autotoc_md55":[5,9,3,6],
+"page_library.html#autotoc_md56":[5,9,3,7],
+"page_library.html#autotoc_md57":[5,9,3,8],
+"page_library.html#autotoc_md58":[5,9,3,9],
+"page_library.html#autotoc_md59":[5,9,4],
+"page_library.html#autotoc_md60":[5,9,4,0],
+"page_library.html#autotoc_md61":[5,9,4,1],
+"page_library.html#autotoc_md62":[5,9,5],
+"page_library.html#autotoc_md63":[5,9,6],
+"page_library.html#autotoc_md64":[5,9,7],
+"page_man_pipewire_1.html":[5,12,0],
+"page_man_pipewire_conf_5.html":[5,12,2],
+"page_man_pipewire_pulse_1.html":[5,12,1],
+"page_man_pw_cat_1.html":[5,12,3],
+"page_man_pw_cli_1.html":[5,12,4],
+"page_man_pw_dot_1.html":[5,12,5],
 "page_man_pw_jack_1.html":[5,12,12],
 "page_man_pw_link_1.html":[5,12,6],
 "page_man_pw_metadata_1.html":[5,12,7],
@@ -45,10 +133,12 @@ var NAVTREEINDEX17 =
 "page_module_raop_sink.html":[6,20],
 "page_module_roc_sink.html":[6,22],
 "page_module_roc_source.html":[6,23],
-"page_module_rt.html":[6,24],
-"page_module_session_manager.html":[6,25],
-"page_module_x11_bell.html":[6,26],
-"page_module_zeroconf_discover.html":[6,27],
+"page_module_rt.html":[6,26],
+"page_module_rtp_sink.html":[6,24],
+"page_module_rtp_source.html":[6,25],
+"page_module_session_manager.html":[6,27],
+"page_module_x11_bell.html":[6,28],
+"page_module_zeroconf_discover.html":[6,29],
 "page_objects_design.html":[5,8],
 "page_objects_design.html#autotoc_md68":[5,8,0],
 "page_objects_design.html#autotoc_md69":[5,8,0,0],
@@ -159,95 +249,5 @@ var NAVTREEINDEX17 =
 "page_spa_pod.html#autotoc_md147":[9,6,4],
 "page_streams.html":[8,2],
 "page_streams.html#sec_buffers":[8,2,4],
-"page_streams.html#sec_connect":[8,2,2],
-"page_streams.html#sec_create":[8,2,1],
-"page_streams.html#sec_format":[8,2,3],
-"page_streams.html#sec_overview":[8,2,0],
-"page_streams.html#sec_stream_configuration":[8,2,7],
-"page_streams.html#sec_stream_disconnect":[8,2,6],
-"page_streams.html#sec_stream_environment":[8,2,8],
-"page_streams.html#sec_streaming":[8,2,5],
-"page_streams.html#ssec_config_properties":[8,2,7,0],
-"page_streams.html#ssec_config_rules":[8,2,7,1],
-"page_streams.html#ssec_consume":[8,2,5,0],
-"page_streams.html#ssec_produce":[8,2,5,1],
-"page_streams.html#ssec_stream_formats":[8,2,2,1],
-"page_streams.html#ssec_stream_target":[8,2,2,0],
-"page_thread_loop.html":[8,3],
-"page_thread_loop.html#sec_thread_loop_create":[8,3,1],
-"page_thread_loop.html#sec_thread_loop_destruction":[8,3,2],
-"page_thread_loop.html#sec_thread_loop_events":[8,3,4],
-"page_thread_loop.html#sec_thread_loop_locking":[8,3,3],
-"page_thread_loop.html#sec_thread_loop_overview":[8,3,0],
-"page_tools.html":[5,12],
-"page_tutorial.html":[7],
-"page_tutorial.html#autotoc_md108":[7,0],
-"page_tutorial1.html":[7,1],
-"page_tutorial1.html#autotoc_md109":[7,1,0],
-"page_tutorial1.html#autotoc_md110":[7,1,1],
-"page_tutorial2.html":[7,2],
-"page_tutorial3.html":[7,3],
-"page_tutorial4.html":[7,4],
-"page_tutorial5.html":[7,5],
-"page_tutorial6.html":[7,6],
-"pages.html":[],
-"spa_2examples_2adapter-control_8c-example.html":[13,24],
-"spa_2examples_2example-control_8c-example.html":[13,25],
-"spa_2examples_2local-libcamera_8c-example.html":[13,26],
-"spa_2examples_2local-v4l2_8c-example.html":[13,27],
-"structitimerspec.html":[11,0,0],
-"structpw__array.html":[10,6,0,1],
-"structpw__array.html#a3d468425a1a0084f98301e2fd9becc6b":[10,6,0,1,1],
-"structpw__array.html#a429b934f5c1580d91af238ac04e44842":[10,6,0,1,2],
-"structpw__array.html#a92ae2df32c3d6935897f41b6e7f5ad3c":[10,6,0,1,3],
-"structpw__array.html#ab0929cdf2f7acb291f2f17be299b8ea5":[10,6,0,1,0],
-"structpw__buffer.html":[10,0,1],
-"structpw__buffer.html#a925734b861209896789573f3b94a61c1":[10,0,1,2],
-"structpw__buffer.html#ab5fe741ec31686febdbc602098945f08":[10,0,1,3],
-"structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090":[10,0,1,0],
-"structpw__buffer.html#ad85549808ad885c57f85e1aee60b8c96":[10,0,1,1],
-"structpw__buffers.html":[10,5,9,1],
-"structpw__buffers.html#ac6dff2ff3c481e5b092fca206e0c144f":[10,5,9,1,3],
-"structpw__buffers.html#ad2d1496ce9316c04921470078b8046c5":[10,5,9,1,2],
-"structpw__buffers.html#adf149a809c1ea9c435ae7439391c87ed":[10,5,9,1,1],
-"structpw__buffers.html#af915317f3448e471390a13c48c0d873e":[10,5,9,1,0],
-"structpw__client.html":[10,4,3,4],
-"structpw__client__endpoint.html":[10,7,4,22],
-"structpw__client__endpoint__events.html":[10,7,4,6],
-"structpw__client__endpoint__events.html#a02d8f4d9cd9f898d3109a64f7afd81e1":[10,7,4,6,4],
-"structpw__client__endpoint__events.html#a12f427748eebbfd39cdc4f75a9db57ed":[10,7,4,6,1],
-"structpw__client__endpoint__events.html#a43e06e14ba4461922bfce4c3c98c13f1":[10,7,4,6,3],
-"structpw__client__endpoint__events.html#a45e7bb70eb2b24c33aad0c82dcf001b6":[10,7,4,6,2],
-"structpw__client__endpoint__events.html#afab781a09b218afdc2c9ffb54502be5e":[10,7,4,6,0],
-"structpw__client__endpoint__methods.html":[10,7,4,7],
-"structpw__client__endpoint__methods.html#a283f6ec14d1a3ff9b0b0aa213b2ea850":[10,7,4,7,1],
-"structpw__client__endpoint__methods.html#a58fe2e1f1524cf0f22dda84f7f9c33e0":[10,7,4,7,0],
-"structpw__client__events.html":[10,4,3,2],
-"structpw__client__events.html#a0ceb2ae8884ca4a30bae720198410075":[10,4,3,2,0],
-"structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254":[10,4,3,2,1],
-"structpw__client__events.html#af685647fe57d1a9dba2a0d89d32aae39":[10,4,3,2,2],
-"structpw__client__info.html":[10,4,3,1],
-"structpw__client__info.html#a8585e5629d10bb4359ede29782fd7c21":[10,4,3,1,0],
-"structpw__client__info.html#a9123521af948ea7b720d1ebb0f39c66b":[10,4,3,1,1],
-"structpw__client__methods.html":[10,4,3,3],
-"structpw__client__methods.html#a17155250b4b575de0530a8d01447148a":[10,4,3,3,3],
-"structpw__client__methods.html#a2804d8a526c068a486a4e261821c9a07":[10,4,3,3,5],
-"structpw__client__methods.html#a298f33a5d81477d06b08f52d233b740a":[10,4,3,3,2],
-"structpw__client__methods.html#a7af9e64e81ebc0b3a7d726ff98e0dd84":[10,4,3,3,4],
-"structpw__client__methods.html#a898d61fc799b5c09421365854020b357":[10,4,3,3,0],
-"structpw__client__methods.html#ad5cf20929a275ce91d7fdbbb80e70be3":[10,4,3,3,1],
-"structpw__client__node.html":[10,7,0,4],
-"structpw__client__node__buffer.html":[10,7,0,1],
-"structpw__client__node__buffer.html#a003e6b6549d0dbd9e2c8a6030a1cfa85":[10,7,0,1,2],
-"structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392":[10,7,0,1,0],
-"structpw__client__node__buffer.html#a1d524a38ed82fb88371d741bcb1e3ff0":[10,7,0,1,1],
-"structpw__client__node__buffer.html#a27039caf89b376d354a33d1559e939b3":[10,7,0,1,3],
-"structpw__client__node__events.html":[10,7,0,2],
-"structpw__client__node__events.html#a0942c754a0fd77db7c9051172b2ac991":[10,7,0,2,10],
-"structpw__client__node__events.html#a0fdb140f41117e7690aca449844d72c2":[10,7,0,2,9],
-"structpw__client__node__events.html#a3802ec24f1305664c8d1b846abc244c8":[10,7,0,2,7],
-"structpw__client__node__events.html#a3d12bf0a63aba14bc897e4ceb51e4fe4":[10,7,0,2,0],
-"structpw__client__node__events.html#a63c10e914836b4c4ffc02be889c717f8":[10,7,0,2,8],
-"structpw__client__node__events.html#a775ca4ec6d6115039b2e8574bef184f2":[10,7,0,2,4],
-"structpw__client__node__events.html#aa25eeb692995699b672f71251ec0b4b6":[10,7,0,2,11]
+"page_streams.html#sec_connect":[8,2,2]
 };
